@@ -3,6 +3,7 @@ import uuid
 import re
 from wsgiref.handlers import format_date_time
 from jaaql.db.db_pg_interface import DBPGInterface, QUERY__dba_query_external
+from jaaql.email.email_manager_service import EmailAttachment
 from jaaql.mvc.base_model import BaseJAAQLModel, VAULT_KEY__jwt_crypt_key
 from jaaql.exceptions.http_status_exception import HttpStatusException, ERR__already_installed, HttpSingletonStatusException
 from os.path import join
@@ -475,7 +476,7 @@ WHERE
 
     def verify_auth_token(self, auth_token: str, ip_address: str):
         decoded = crypt_utils.jwt_decode(self.vault.get_obj(VAULT_KEY__jwt_crypt_key), auth_token, JWT_PURPOSE__oauth)
-        if not decoded or decoded[KEY__ip_address] != ip_address:
+        if not decoded or (decoded[KEY__ip_address] != ip_address and ip_address not in IPS__local):
             raise HttpStatusException(ERR__invalid_token, HTTPStatus.UNAUTHORIZED)
 
         validate_is_most_recent_password(self.jaaql_lookup_connection, decoded[KEY__account_id], decoded[KEY__password],
@@ -654,34 +655,59 @@ WHERE
             KEY__username: account[KG__account__username]
         }
 
-    def send_email(self, is_the_anonymous_user: bool, account_id: str, inputs: dict):
+    def send_email(self, is_the_anonymous_user: bool, account_id: str, inputs: dict, username: str, auth_token: str):
         app = application__select(self.jaaql_lookup_connection, inputs[KEY__application])
 
         fetched_template = email_template__select(self.jaaql_lookup_connection, inputs[KEY__application], inputs[KEY__template])
         if is_the_anonymous_user and not fetched_template[KG__email_template__can_be_sent_anonymously]:
             raise HttpStatusException("Cannot send this template anonymously")
 
-        parameters = inputs[KEY__parameters]
-        non_sanitized_parameters = None
+        # [25/10/23] The below code is disabled as send email allows only for sending to the current email
+        # Anonymous email templates must be sent to the domain recipient
+        # if fetched_template[KG__email_template__can_be_sent_anonymously]:
+        #     if not fetched_template[KG__email_template__dispatcher_domain_recipient]:
+        #         raise HttpStatusException("Must specify dispatcher domain recipient if sending anonymous emails!")
 
-        # Anonymous email templates are sent with a lower level of scrutiny but must be sent to the domain recipient
-        if fetched_template[KG__email_template__can_be_sent_anonymously]:
-            non_sanitized_parameters = parameters
-            parameters = None
+        # recipient = fetched_template[KG__email_template__dispatcher_domain_recipient].split("@")[0]
+        # domain = email_dispatcher__select(self.jaaql_lookup_connection, self.get_db_crypt_key(), inputs[KEY__application],
+        #                                   fetched_template[KG__email_template__dispatcher])[KG__email_dispatcher__username].split("@")[1]
+        # recipient = recipient + "@" + domain
 
-            if not fetched_template[KG__email_template__dispatcher_domain_recipient]:
-                raise HttpStatusException("Must specify dispatcher domain recipient if sending anonymous emails!")
+        submit_data = {
+            KEY__application: inputs[KG__security_event__application],
+            KEY__parameters: inputs[KEY__parameters],
+            KEY__schema: fetched_template[KG__email_template__validation_schema]
+        }
 
-        recipient = fetched_template[KG__email_template__dispatcher_domain_recipient].split("@")[0]
-        domain = email_dispatcher__select(self.jaaql_lookup_connection, self.get_db_crypt_key(), inputs[KEY__application],
-                                          fetched_template[KG__email_template__dispatcher])[KG__email_dispatcher__username].split("@")[1]
-        recipient = recipient + "@" + domain
+        data_relation = fetched_template[KG__email_template__data_validation_view]
+        if re.match(REGEX__dmbs_object_name, data_relation) is None:
+            raise HttpStatusException("Unsafe data relation specified for email template")
+        safe_parameters = []
+        for key, val in inputs[KEY__parameters].items():
+            if re.match(REGEX__dmbs_object_name, key) is None:
+                raise HttpStatusException("Unsafe parameter specified for email template")
+            safe_parameters.append(f'{key} = :{key}')  # Ignore pycharm PEP issue
+        where_clause = " AND ".join(safe_parameters)
+        submit_data[KEY_query] = f'SELECT * FROM {data_relation} WHERE {where_clause}'  # Ignore pycharm PEP issue
+        # We now get the data that can be shown in the email
+        email_replacement_data = submit(self.vault, self.config, self.get_db_crypt_key(), self.jaaql_lookup_connection,
+                                        submit_data, account_id, None, self.cached_canned_query_service,
+                                        as_objects=True, singleton=True)
 
-        self.email_manager.send_email(self.vault, self.config, self.get_db_crypt_key(), self.jaaql_lookup_connection,
-                                      inputs[KG__security_event__application], inputs[KEY__template],
-                                      app[KG__application__artifacts_source],
-                                      app[KG__application__base_url], account_id, parameters,
-                                      none_sanitized_parameters=non_sanitized_parameters, recipient=recipient)
+        document_templates = fetch_document_templates_for_email_template(self.jaaql_lookup_connection, inputs[KEY__application], inputs[KEY__template])
+        attachments = [
+            EmailAttachment(
+                template[KG__document_template__name], template[KG__document_template__application], inputs[KEY__parameters],
+                template[KG__document_template__email_template]
+            )
+            for template in document_templates
+        ]
+
+        self.email_manager.construct_and_send_email(app[KG__application__artifacts_source],
+                                                    fetched_template[KG__email_template__dispatcher], fetched_template,
+                                                    username, email_replacement_data,
+                                                    attachments=attachments, attachment_access_token=auth_token,
+                                                    attachment_base_url="http://localhost" if self.is_container else "")
 
     def reset_password(self, inputs: dict):
         app = application__select(self.jaaql_lookup_connection, inputs[KG__security_event__application])
@@ -791,7 +817,7 @@ WHERE
             conn = account_db_interface.get_conn()
 
             ret = submit(self.vault, self.config, self.get_db_crypt_key(), self.jaaql_lookup_connection, submit_data, account_id, None,
-                         self.cached_canned_query_service, as_objects=False, singleton=True, keep_alive_conn=True)
+                         self.cached_canned_query_service, as_objects=False, singleton=True, keep_alive_conn=True, conn=conn, interface=account_db_interface)
             ret = objectify(ret[list(ret.keys())[-1]], singleton=True)
 
             # This is the permissions check. It is an update that returns something that is ignored
