@@ -3,12 +3,13 @@ from os.path import join, exists, dirname
 from datetime import datetime
 import os
 import glob
-from jaaql.constants import DIR__config, FILE__config, CONFIG_KEY__server, CONFIG_KEY_SERVER__port, ENVIRON__install_path, PORT__ems, PORT__mms,\
-    VAULT_KEY__super_db_credentials
+from jaaql.constants import DIR__config, FILE__config, CONFIG_KEY__server, CONFIG_KEY_SERVER__port, ENVIRON__install_path, PORT__ems, PORT__mms, \
+    VAULT_KEY__db_crypt_key
 from jaaql.config_constants import *
 from jaaql.db.db_interface import DBInterface
 from jaaql.db.db_utils import create_interface
 from jaaql.constants import VAULT_KEY__jaaql_lookup_connection
+from jaaql.utilities.crypt_utils import ENCODING__ascii
 import configparser
 import time
 import urllib.parse
@@ -100,7 +101,7 @@ def await_jaaql_bootup(config, is_gunicorn: bool):
             return requests.get(base_url + "/internal/is_installed").status_code
         except:
             pass
-        time.sleep(5)
+        time.sleep(0.5)
 
 
 def await_jaaql_installation(config, is_gunicorn: bool):
@@ -150,7 +151,5 @@ def get_db_connection_as_jaaql(config, vault, db: str):
     return create_interface(config, address, port, db, username, password)
 
 
-def create_interface_for_db(vault, config, user_id: str, database: str, sub_role: str = None):
-    jaaql_uri = vault.get_obj(VAULT_KEY__super_db_credentials)
-    address, port, _, username, password = DBInterface.fracture_uri(jaaql_uri)
-    return create_interface(config, address, port, database, username, password=password, role=user_id, sub_role=sub_role)
+def get_db_crypt_key(vault):
+    return vault.get_obj(VAULT_KEY__db_crypt_key).encode(ENCODING__ascii)
